summaryrefslogtreecommitdiff
path: root/gnu/installer
diff options
context:
space:
mode:
authorRutherther <rutherther@ditigal.xyz>2026-01-10 22:24:32 +0100
committerRutherther <rutherther@ditigal.xyz>2026-01-14 10:46:41 +0100
commit056dd112aa4e67bfccb7e19709da54e249b5d512 (patch)
treeaa155e0aeed2699427608925d561c2bd032d21a7 /gnu/installer
parent9448ec6fb20a737a852e8624b5611950886feaaa (diff)
installer: partition: Force msdos on Hurd.
Since Hurd always uses Legacy BIOS bootloader, do not offer GPT label. * gnu/installer/newt/partition.scm (run-label-page): Force MSDOS for Hurd target. Change-Id: Ib8bb1175f85e8f6084683a747303e3e19f20be42 Signed-off-by: Rutherther <rutherther@ditigal.xyz>
Diffstat (limited to 'gnu/installer')
-rw-r--r--gnu/installer/newt/partition.scm29
1 files changed, 16 insertions, 13 deletions
diff --git a/gnu/installer/newt/partition.scm b/gnu/installer/newt/partition.scm
index 3a7e6795776..eb99f9860fc 100644
--- a/gnu/installer/newt/partition.scm
+++ b/gnu/installer/newt/partition.scm
@@ -108,20 +108,23 @@ all data on disk will be lost, are you sure you want to proceed?") item)
(define (run-label-page button-text button-callback)
"Run a page asking the user to select a partition table label."
- ;; Force the GPT label if UEFI is supported.
- (if (efi-installation?)
- ((run-label-confirmation-page button-callback) "gpt")
- (run-listbox-selection-page
- #:info-text (G_ "Select a new partition table type. \
+ ;; Force the GPT label if UEFI is supported.
+ (cond ((efi-installation?)
+ ((run-label-confirmation-page button-callback) "gpt"))
+ ;; Force the MSDOS label on Hurd.
+ ((target-hurd?)
+ ((run-label-confirmation-page button-callback) "msdos"))
+ (else (run-listbox-selection-page
+ #:info-text (G_ "Select a new partition table type. \
Be careful, all data on the disk will be lost.")
- #:title (G_ "Partition table")
- #:listbox-items '("msdos" "gpt")
- #:listbox-default-item (if (target-hurd?) "msdos" "gpt")
- #:listbox-item->text identity
- #:listbox-callback-procedure
- (run-label-confirmation-page button-callback)
- #:button-text button-text
- #:button-callback-procedure button-callback)))
+ #:title (G_ "Partition table")
+ #:listbox-items '("msdos" "gpt")
+ #:listbox-default-item (if (target-hurd?) "msdos" "gpt")
+ #:listbox-item->text identity
+ #:listbox-callback-procedure
+ (run-label-confirmation-page button-callback)
+ #:button-text button-text
+ #:button-callback-procedure button-callback))))
(define (run-type-page partition)
"Run a page asking the user to select a partition type."